==> arla_0.35.6.orig.tar.gz: arla-0.35.6/milko/lib/dpart/dpart.h <==
/*
 * Copyright (c) 1999 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/* $Id: dpart.h,v 1.6 2000/12/29 20:12:36 tol Exp $ */

#ifndef __FILBULKE_DPART_H
#define __FILBULKE_DPART_H 1

struct dp_part {
    char *part;
    int num;
    int ref;
};

extern char *dpart_root;

#define DP_NUMBER(dp) ((dp)->num)
#define DP_NAME(dp)   ((dp)->part)

int
dp_create (u_int32_t num, struct dp_part **dp);

void
dp_ref (struct dp_part *dp);

void
dp_free (struct dp_part *dp);

int
dp_find (struct dp_part **dp);

int
dp_findvol (struct dp_part *d, void (*cb)(void *, int), void *data);

int
dp_parse (const char *str, u_int32_t *num);

struct dp_part *
dp_getpart (const char *str);

#endif /* __FILBULKE_DPART_H */

==> arla_0.36.2.orig.tar.gz: arla-0.36.2/milko/lib/dpart/dpart.h <==
/*
 * Copyright (c) 1999 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/* $Id: dpart.h,v 1.8 2002/02/07 17:59:45 lha Exp $ */

#ifndef __FILBULKE_DPART_H
#define __FILBULKE_DPART_H 1

struct dp_part {
    char *part;
    int num;
    int ref;
};

extern char *dpart_root;

#define DP_NUMBER(dp) ((dp)->num)
#define DP_NAME(dp)   ((dp)->part)

int
dp_create (uint32_t num, struct dp_part **dp);

void
dp_ref (struct dp_part *dp);

void
dp_free (struct dp_part *dp);

int
dp_find (struct dp_part **dp);

int
dp_findvol (struct dp_part *d, void (*cb)(void *, int), void *data);

int
dp_parse (const char *str, uint32_t *num);

struct dp_part *
dp_getpart (const char *str);

int
dp_getstats (struct dp_part *dp, long *availblocks, long *totalblocks);

#endif /* __FILBULKE_DPART_H */
